/***************************************************************************
	file:			eeprom.h
	product:	API-004
	descr:		Diese API ermoeglicht das Benutzen von I2C EEPROM.
						Man kann einzelne Bytes in den EEPROM Speicher schreiben und
						aus dem EEPROM lesen.
						Diese API ist mit stack2Learn I2C-006 1k EEPROM und I2C-007 64k EEPROM kompatibel.

						Folgende Voraussetzungen muessen erfuellt sein:
							- Inkludierung der API-002: Emulator der I2C (TWI) Schnittstelle wird vorausgesetzt.
							- Die bertragung der Bytes ber I2C Schnittstelle, darf nicht unterbrochen werden,
								z. B. von einem Interrupt.
							- Jeder Schreibzyklus wird mit einer Stoppbedingung beendet,	
								d.h tWR Write Cycle Time (EEPROM interner Schreibzyklus, waehrend dieser Zeit
								reagiert EEPROM auf keinen Befehl von auen)von ca 5 ms muss eingehalten werden.

	date: 		10.2013 - first release

	version 	1.0
	compiler:	Keil Cx51 V9.05

	mc:				AT89C5131A
	crystal:	24MHz

	author: 	Viktor Schabelski info@approbe.de
	licence:	Creative Commons Lizenz
                http://www.stack2Learn.de/cc.html

**************************************************/


# ifndef _EEPROM_H
	# define _EEPROM_H

/*-----------------------------------------------------------------------------
	includes
---------------------------------------------------*/
#include "eeprom_config.h"

/*-----------------------------------------------------------------------------
	constans adn globals
---------------------------------------------------*/
// Error code fuer EEPROM
typedef enum _errorCodeEEPROM{
	EEPROM_SUCCESS = 0x00,
	EEPROM_BUSY = 0x01,
	EEPROM_WRITE_FAIL = 0x02,
	EEPROM_READ_FAIL = 0x03,
	EEPROM_ERROR = 0x04
}errorCodeEEPROM_t;


/*-----------------------------------------------------------------------------
	api
---------------------------------------------------*/
// Schreibe ein Byte in EEPROM
errorCodeEEPROM_t EEPROM_WriteByte(unsigned int address, unsigned char dataByte);
// Lese ein Byte aus dem EEPROM
errorCodeEEPROM_t EEPROM_ReadByte(unsigned int address, unsigned char* dataByte);



#endif